diff -u /dev/null source/org/jivesoftware/smack/IChat.java --- /dev/null   2005-01-08 04:31:38.000000000 -0500
+++ source/org/jivesoftware/smack/IChat.java      2005-01-16 14:57:24.000000000 -0500
@@ -0,0 +1,38 @@
+/**
+ * $RCSfile$
+ * $Revision$
+ * $Date$
+ *
+ * Copyright 2004 Jive Software.
+ *
+ * All rights reserved. Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.jivesoftware.smack;
+
+import java.util.Iterator;
+
+import org.jivesoftware.smack.packet.Message;
+
+public interface IChat {
+       void addMessageListener(PacketListener listener);
+
+       Message createMessage();
+       void sendMessage(String text) throws XMPPException;
+       void sendMessage(Message message) throws XMPPException;
+       Message pollMessage();
+       Message nextMessage();
+       Message nextMessage(long timeout);
+
+       int getOccupantsCount();
+       Iterator getOccupants();
+}
diff -u -r1.13 Chat.java
--- source/org/jivesoftware/smack/Chat.java	2 Nov 2004 23:53:22 -0000	1.13
+++ source/org/jivesoftware/smack/Chat.java	16 Jan 2005 20:05:00 -0000
@@ -20,6 +20,10 @@
 
 package org.jivesoftware.smack;
 
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Iterator;
+
 import org.jivesoftware.smack.packet.Message;
 import org.jivesoftware.smack.util.StringUtils;
 import org.jivesoftware.smack.filter.*;
@@ -37,7 +41,7 @@
  * @see XMPPConnection#createChat(String)
  * @author Matt Tucker
  */
-public class Chat {
+public class Chat implements IChat {
 
     /**
      * A prefix helps to make sure that ID's are unique across mutliple instances.
@@ -156,6 +160,29 @@
     }
 
     /**
+     * Returns the number of occupants in the group chat. This is
+     * always two for a regular chat.
+     * 
+     * @return the number of occupants in the chat (always two).
+     */
+	public int getOccupantsCount() {
+		return 2;
+	}
+
+	/**
+	 * Returns an Iterator (over Strings) containing the list of fully qualified occupants
+	 * of the chat. The collection always contains two elements for a chat.
+     *
+     * @return an Iterator over the full XMPP address of the chat occupants.
+	 */
+	public Iterator getOccupants() {
+		List occupants = new ArrayList(2);
+		occupants.add(connection.getUser());
+		occupants.add(participant);
+		return occupants.iterator();
+	}
+
+    /**
      * Sends the specified text as a message to the other chat participant.
      * This is a convenience method for:
      *
@@ -263,4 +290,4 @@
         }
         catch (Exception e) {}
     }
-}
\ No newline at end of file
+}
diff -u -r1.9 MultiUserChat.java
--- source/org/jivesoftware/smackx/muc/MultiUserChat.java	11 Jan 2005 17:34:49 -0000	1.9
+++ source/org/jivesoftware/smackx/muc/MultiUserChat.java	16 Jan 2005 20:05:07 -0000
@@ -42,7 +42,7 @@
  *
  * @author Gaston Dombiak
  */
-public class MultiUserChat {
+public class MultiUserChat implements IChat {
 
     private final static String discoNamespace = "http://jabber.org/protocol/muc";
     private final static String discoNode = "http://jabber.org/protocol/muc#rooms";
